@@ -24,8 +24,6 @@ from collections import defaultdict
 
 import dendropy
 
-from fuzzywuzzy import fuzz
-
 from biolib.common import check_file_exists, make_sure_path_exists, is_float
 from biolib.external.execute import check_dependencies
 from biolib.taxonomy import Taxonomy
@@ -33,6 +31,7 @@ from biolib.newick import parse_label
 
 from gtdb_validation_tk.common import read_gtdb_metadata, canonical_species_name, canonical_wgs_id
 from gtdb_validation_tk.check_taxonomy_file import CheckTaxonomyFile
+from gtdb_validation_tk.check_taxa import CheckTaxa
 from gtdb_validation_tk.suffix_table import SuffixTable
 from gtdb_validation_tk.red_check import RED_Check
 from gtdb_validation_tk.missing_genera import MissingGenera
@@ -55,6 +54,7 @@ csv.field_size_limit(min(2**31-1, sys.maxsize))
 class OptionsParser(object):
     def __init__(self):
         """Initialization"""
+
         self.logger = logging.getLogger()
 
     def check_file(self, options):
@@ -63,71 +63,16 @@ class OptionsParser(object):
         check_file_exists(options.input_taxonomy)
 
         taxonomy = Taxonomy().read(options.input_taxonomy)
-        
-        # identify cases where root of child is highly similar to,
-        # but not identical to root of parent
-        # (e.g. f__Defferisomataceae; g__Deferrisoma -> missing 'f')
-        self.logger.info('Identifying parent-child taxa with sufficiently similar, but non-identical names to suggest a type.')
-        rank_suffix = {1: 'ota', 2: 'ia',  3: 'ales', 4: 'aceae', 5: None}
-        potential_issues = {}
-        for gid, taxa in taxonomy.items():
-            for rank_idx in range(1, 5):
-                # get parent name
-                parent = taxa[rank_idx][3:]
-                if '_' in parent:
-                    parent = parent[0:parent.rfind('_')]
-                    
-                if not parent.endswith(rank_suffix[rank_idx]):
-                    continue
-                
-                parent_root = parent.replace(rank_suffix[rank_idx], '')
-                
-                # get child name
-                child = taxa[rank_idx+1][3:]
-                if '_' in child:
-                    child = child[0:child.rfind('_')]
-                    
-                if rank_suffix[rank_idx+1]:
-                    if not child.endswith(rank_suffix[rank_idx+1]):
-                        continue
-                    child_root = child.replace(rank_suffix[rank_idx+1], '')
-                else:
-                    # genera have no fixed suffix
-                    child_root = child
-                    
-                # limit roots to shortest string as trailing characters
-                # often mismatch
-                # (e.g.  f__Streptomycetaceae -> Streptomycet;
-                #        g__Streptomyces -> Streptomyces)
-                min_root_len = min(len(parent_root), len(child_root))
-                parent_root = parent_root[0:min_root_len]
-                child_root = child_root[0:min_root_len]
-                
-                fuzzy_score = fuzz.ratio(parent_root, child_root)
-                prefix_score = 0
-                for idx in range(min_root_len):
-                    if parent_root[idx] != child_root[idx]:
-                        break
-                        
-                    prefix_score += 1
-                prefix_score = int(float(prefix_score)*100 / min_root_len)
 
-                if (fuzzy_score != 100 and fuzzy_score >= 75 
-                    and prefix_score != 100 and prefix_score <= 50 and prefix_score != 0):
-                    potential_issues['{}#{}'.format(parent, child)] = (parent_root, child_root, fuzzy_score, prefix_score)
+        # check for potential typos in taxon names
+        p = CheckTaxa()
+        p.check_for_typos(taxonomy)
 
-        print(' - identified {:,} potential issues'.format(len(potential_issues)))
-        if len(potential_issues) > 0:
-            for conflict, tokens in potential_issues.items():
-                parent, child = conflict.split('#')
-                parent_root, child_root, fuzzy_score, prefix_score = tokens
-                print(' - {} {}: fuzzy score = {}, prefix score = {}'.format(
-                        parent,
-                        child,
-                        fuzzy_score,
-                        prefix_score))
+        # check that taxon name has a valid format
+        p.valid_taxon_name(taxonomy)
 
         # perform standard taxonomy file checks
+        self.logger.info('Performing standard taxonomy file checks.')
         p = CheckTaxonomyFile()
         p.check(taxonomy,
                 check_prefixes=True,
@@ -213,6 +158,39 @@ class OptionsParser(object):
 
         self.logger.info('Finished performing validation tests.')
 
+    def check_dups(self, options):
+        """Report taxa that appear in Bacteria and Archaea."""
+
+        check_file_exists(options.bac_taxonomy)
+        check_file_exists(options.ar_taxonomy)
+
+        bac_taxonomy = Taxonomy().read(options.bac_taxonomy)
+        bac_taxa = defaultdict(list)
+        for gid, taxa in bac_taxonomy.items():
+            for taxon in taxa:
+                bac_taxa[taxon].append(gid)
+
+        ar_taxonomy = Taxonomy().read(options.ar_taxonomy)
+        ar_taxa = defaultdict(list)
+        for gid, taxa in ar_taxonomy.items():
+            for taxon in taxa:
+                ar_taxa[taxon].append(gid)
+
+        dup_taxa = set(bac_taxa).intersection(ar_taxa)
+        if len(dup_taxa) > 0:
+            print('')
+            print('Taxonomies contain duplicate taxon names:')
+            for dup_taxon in dup_taxa:
+                print('{}: e.g. {} and {}'.format(
+                    dup_taxon,
+                    bac_taxa[dup_taxon][0],
+                    ar_taxa[dup_taxon][0]))
+            print('')
+        else:
+            self.logger.info('No duplicate names identified.')
+
+        self.logger.info('Finished performing validation tests.')
+
     def check_suffix(self, options):
         """Report taxa with potentially erroneous polyphyly suffix designations."""
 
@@ -326,7 +304,7 @@ class OptionsParser(object):
             support, taxon, _aux_info = parse_label(n.label)
             if not support:
                 continue
-                
+
             if taxon and support < options.min_support:
                 poor_support[taxon] = support
 
@@ -510,9 +488,6 @@ class OptionsParser(object):
         check_file_exists(options.input_taxonomy)
         check_file_exists(options.gtdb_metadata_file)
         check_file_exists(options.sp_classification_ledger)
-        check_file_exists(options.genus_ledger)
-        check_file_exists(options.gtdb_synonym_file)
-        check_file_exists(options.user_genome_id_table)
         make_sure_path_exists(options.output_dir)
 
         p = CheckSpeciesNames()
@@ -520,8 +495,6 @@ class OptionsParser(object):
                         options.gtdb_metadata_file,
                         options.sp_classification_ledger,
                         options.genus_ledger,
-                        options.gtdb_synonym_file,
-                        options.user_genome_id_table,
                         options.output_dir)
 
         self.logger.info('Done.')
@@ -533,7 +506,6 @@ class OptionsParser(object):
         check_file_exists(options.gtdb_metadata_file)
         check_file_exists(options.sp_classification_ledger)
         check_file_exists(options.gtdb_synonym_file)
-        check_file_exists(options.user_genome_id_table)
         make_sure_path_exists(options.output_dir)
 
         p = CheckSpeciesNames()
@@ -541,7 +513,6 @@ class OptionsParser(object):
                          options.gtdb_metadata_file,
                          options.sp_classification_ledger,
                          options.gtdb_synonym_file,
-                         options.user_genome_id_table,
                          options.output_dir)
 
         self.logger.info('Done.')
@@ -712,56 +683,57 @@ class OptionsParser(object):
         """Add a zero branch length sister node to each current leaf node."""
 
         # add dummy nodes to tree
-        check_file_exists(options.input_tree)
+        if options.input_tree.lower() != 'none':
+            check_file_exists(options.input_tree)
 
-        self.logger.info('Reading input tree.')
-        tree = dendropy.Tree.get_from_path(options.input_tree,
-                                           schema='newick',
-                                           rooting='force-rooted',
-                                           preserve_underscores=True)
-        self.logger.info(' ...identified {} leaf nodes.'.format(
-            sum([1 for leaf in tree.leaf_node_iter()])))
+            self.logger.info('Reading input tree.')
+            tree = dendropy.Tree.get_from_path(options.input_tree,
+                                               schema='newick',
+                                               rooting='force-rooted',
+                                               preserve_underscores=True)
+            self.logger.info(' ...identified {} leaf nodes.'.format(
+                sum([1 for leaf in tree.leaf_node_iter()])))
 
-        # create zero branch length sister node to each leaf node
-        self.logger.info('Adding dummy leaf nodes to tree.')
-        for leaf in tree.leaf_node_iter():
-            gid = leaf.taxon.label
+            # create zero branch length sister node to each leaf node
+            self.logger.info('Adding dummy leaf nodes to tree.')
+            for leaf in tree.leaf_node_iter():
+                gid = leaf.taxon.label
 
-            leaf.label = None
-            leaf.taxon = None
-            leaf.new_child(label=gid,
-                           edge_length=0.0)
-            leaf.new_child(label='D-' + gid,
-                           edge_length=0.0)
+                leaf.label = None
+                leaf.taxon = None
+                leaf.new_child(label=gid,
+                               edge_length=0.0)
+                leaf.new_child(label='D-' + gid,
+                               edge_length=0.0)
 
-        # write new tree to file
-        base, ext = os.path.splitext(options.input_tree)
-        output_tree = base + '.dummy_nodes' + ext
-        self.logger.info(
-            'Writing modified tree to: {}'.format(output_tree))
-        tree.write_to_path(output_tree,
-                           schema='newick',
-                           suppress_rooting=True,
-                           suppress_leaf_node_labels=False,
-                           unquoted_underscores=True)
+            # write new tree to file
+            base, ext = os.path.splitext(options.input_tree)
+            output_tree = base + '.dummy_nodes' + ext
+            self.logger.info(
+                'Writing modified tree to: {}'.format(output_tree))
+            tree.write_to_path(output_tree,
+                               schema='newick',
+                               suppress_rooting=True,
+                               suppress_leaf_node_labels=False,
+                               unquoted_underscores=True)
 
         # add dummy nodes to taxonomy file
         if options.taxonomy_file:
             self.logger.info('Adding dummy nodes to taxonomy file.')
-            
+
             base, ext = os.path.splitext(options.taxonomy_file)
             output_taxonomy_file = base + '.dummy_nodes' + ext
             fout = open(output_taxonomy_file, 'w')
-            
+
             with open(options.taxonomy_file) as f:
                 for line in f:
                     fout.write(line)
                     fout.write('D-'+line)
-          
+
             fout.close()
-            
+
             self.logger.info(
-            'Writing modified taxonomy file to: {}'.format(output_taxonomy_file))
+                'Writing modified taxonomy file to: {}'.format(output_taxonomy_file))
 
         self.logger.info('Done.')
 
@@ -811,6 +783,8 @@ class OptionsParser(object):
             self.check_file(options)
         elif options.subparser_name == 'check_tree':
             self.check_tree(options)
+        elif options.subparser_name == 'check_dups':
+            self.check_dups(options)
         elif options.subparser_name == 'check_suffix':
             self.check_suffix(options)
         elif options.subparser_name == 'check_spelling':
